﻿// Copyright (c) 2020, Identix identix@identix.com.br
// 
// Permission to use, copy, modify, and/or distribute this software for any purpose with or without fee is hereby granted, provided that the above copyright notice and this permission notice appear in all copies.
// 
// THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

using System;
using System.Threading;
using IRI.Win32.CSharp.IRIWrapper;

namespace Identix.SerialSDK.Examples.KillTag
{
    class Program
    {
        static void Main(string[] args)
        {
            try
            {
                Console.Write("Inform the COM port number: ");
                string comPort = Console.ReadLine();
                Console.WriteLine("COM{0}", comPort);

                // Register the callbacks
                ReaderHelper.Instance.TagReported += OnTagReported;
                ReaderHelper.Instance.TagOpCompleted += OnTagOpCompleted;

                // Connect to COM port, make sure to have installed compatible driver
                ReaderHelper.Instance.Connect("COM" + comPort.Trim());
                ReaderHelper.Instance.SoftReset();

                ReaderHelper.Instance.Start();
                Thread.Sleep(1000);
                ReaderHelper.Instance.Stop();

                string currentEpc = "000000000000000000000000";
                string newKillPassword = "00000000";
                string accessPassword = "00000000";

                if (!string.IsNullOrEmpty(currentEpc))
                {
                    ipj_error error = ReaderHelper.Instance.ChangeKillPassword(currentEpc, newKillPassword, accessPassword);
                    Console.WriteLine("ipj_error: " + error);

                    if (error == ipj_error.E_IPJ_ERROR_SUCCESS)
                    {
                        error = ReaderHelper.Instance.ProgramKill(currentEpc, newKillPassword);
                        Thread.Sleep(100);
                        Console.WriteLine("ipj_error: " + error);
                    }

                    if (!ReaderHelper.Instance.IsInventoryRunning())
                    {
                        ReaderHelper.Instance.Start();
                        Thread.Sleep(1000);
                        ReaderHelper.Instance.Stop();
                    }
                }
                else
                {
                    Console.WriteLine("ERROR: tag not detected.");
                }

                // Disconnect
                ReaderHelper.Instance.Disconnect();

                Console.WriteLine("Press any key to continue...");
                Console.ReadLine();
            }
            catch (Exception ex)
            {
                Console.WriteLine(DateTime.Now.ToString() + "Unexpected error: " + ex.Message);

                Console.WriteLine("Press any key to continue...");
                Console.ReadLine();
            }
        }

        private static void OnTagReported(Tag tagReported)
        {
            Console.WriteLine("EPC: " + tagReported.Epc);
        }

        private static void OnTagOpCompleted(TagOpResult tagOpResult)
        {
            Console.WriteLine("Op ID: " + tagOpResult.TagOpId + ", result: " + tagOpResult.Result);
        }
    }
}
