﻿// Copyright (c) 2020, Identix identix@identix.com.br
// 
// Permission to use, copy, modify, and/or distribute this software for any purpose with or without fee is hereby granted, provided that the above copyright notice and this permission notice appear in all copies.
// 
// THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

using System;
using System.Threading;
using IRI.Win32.CSharp.IRIWrapper;

namespace Identix.SerialSDK.Examples.ReadTags
{
    /// <summary>
    /// IRI Wrapper example for simple inventory with a read timeout
    /// </summary>
    class Program
    {
        private static uint reads = 0;

        static void Main(string[] args)
        {
            try
            {
                Console.Write("Inform the COM port number: ");
                string comPort = Console.ReadLine();
                Console.WriteLine("COM{0}", comPort);

                // Register the callback
                ReaderHelper.Instance.TagReported += OnTagReported;

                // Connect to COM port, make sure to have installed compatible driver
                ReaderHelper.Instance.Connect("COM" + comPort.Trim());

                // As a good practice we will reset the reader to clean up old configurations
                ReaderHelper.Instance.SoftReset();

                // Start inventory
                ReaderHelper.Instance.Start();

                Thread.Sleep(1000);

                // Stop inventory
                ReaderHelper.Instance.Stop();

                // Disconnect
                ReaderHelper.Instance.Disconnect();

                Console.WriteLine("Reads: " + reads);
                Console.WriteLine("Press any key to continue...");
                Console.ReadLine();
            }
            catch (Exception ex)
            {
                Console.WriteLine("Unexpected error: " + ex.Message);

                Console.WriteLine("Press any key to continue...");
                Console.ReadLine();
            }
        }

        // The tag read handler
        private static void OnTagReported(Tag tagReported)
        {
            Console.WriteLine("EPC: " + tagReported.Epc);
            reads++;
        }
    }
}