﻿// Copyright (c) 2020, Identix identix@identix.com.br
// 
// Permission to use, copy, modify, and/or distribute this software for any purpose with or without fee is hereby granted, provided that the above copyright notice and this permission notice appear in all copies.
// 
// THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

using System;
using System.Threading;
using IRI.Win32.CSharp.IRIWrapper;

namespace Identix.SerialSDK.Examples.ReadUserMemory
{
    /// <summary>
    /// IRI Wrapper example for tag access operation: user memory read
    /// </summary>
    class Program
    {
        private static string targetEpc = "AAAA00000000000000000602";
        private static string accessPassword = "00000000";
        private static string userMemoryData = "";

        static void Main(string[] args)
        {
            try
            {
                Console.Write("Inform the COM port number: ");
                string comPort = Console.ReadLine();
                Console.WriteLine("COM{0}", comPort);

                // Register the callbacks
                ReaderHelper.Instance.TagReported += OnTagReported;

                // Connect to COM port, make sure to have installed compatible driver       
                ReaderHelper.Instance.Connect("COM" + comPort.Trim());

                // As a good practice we will reset the reader to clean up old configurations
                ReaderHelper.Instance.SoftReset();

                // Create optation to read the user memory
                TagOpSequence tagOpSequence = new TagOpSequence();
                tagOpSequence.SequenceId = ReaderHelper.Instance.GetNextTagSequenceId();
                TagOp tagOp = new TagOp();
                tagOp.TagOpId = ReaderHelper.Instance.GetNextTagOpId();
                tagOpSequence.TargetEpc = targetEpc;
                tagOp.TagOperationType = ipj_tag_operation_type.E_IPJ_TAG_OPERATION_TYPE_READ;
                tagOp.Bank = ipj_mem_bank.E_IPJ_MEM_BANK_USER;
                tagOp.AccessPassword = accessPassword;
                tagOp.UserMemorywordCountToRead = 2;
                tagOpSequence.TagOps.Add(tagOp);
                ReaderHelper.Instance.AddTagOpSequence(tagOpSequence);

                // Start inventory
                ReaderHelper.Instance.Start();

                Thread.Sleep(1000);

                // Stop inventory
                ReaderHelper.Instance.Stop();

                // Disconnect
                ReaderHelper.Instance.Disconnect();

                Console.WriteLine("User memory data: " + userMemoryData);

                Console.WriteLine("Press any key to continue...");
                Console.ReadLine();
            }
            catch (Exception ex)
            {
                Console.WriteLine("Unexpected error: " + ex.Message);

                Console.WriteLine("Press any key to continue...");
                Console.ReadLine();
            }
        }

        // The tag read handler
        private static void OnTagReported(Tag tagReported)
        {
            if (tagReported.OperationType == "READ" && tagReported.OperationResult == "SUCCESS")
            {
                if (string.IsNullOrEmpty(userMemoryData))
                {
                    userMemoryData = tagReported.OperationData;

                    Console.WriteLine("EPC: " + tagReported.Epc + ", Operation: " + tagReported.OperationType + ", Result: " + tagReported.OperationResult + ", Data: " + tagReported.OperationData);
                }
            }
        }
    }
}