﻿// Copyright (c) 2020, Identix identix@identix.com.br
// 
// Permission to use, copy, modify, and/or distribute this software for any purpose with or without fee is hereby granted, provided that the above copyright notice and this permission notice appear in all copies.
// 
// THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

using System;
using System.Threading;
using IRI.Win32.CSharp.IRIWrapper;

namespace Identix.SerialSDK.Examples.SetConfiguration
{
    /// <summary>
    /// IRI Wrapper example on how to set reader configurations using the configuration Keys
    /// </summary>
    class Program
    {
        static void Main(string[] args)
        {
            try
            {
                Console.Write("Inform the COM port number: ");
                string comPort = Console.ReadLine();
                Console.WriteLine("COM{0}", comPort);

                // Register the callback
                ReaderHelper.Instance.TagReported += OnTagReported;

                //Connect to COM port, make sure to have installed compatible driver
                ReaderHelper.Instance.Connect("COM" + comPort.Trim());

                // As a good practice we will reset the reader to clean up old configurations:
                ReaderHelper.Instance.SoftReset();

                // Create settings using default settings
                ReaderSettings readerSettings = ReaderHelper.Instance.GetDefaultReaderSettings();

                // Configure regions
                readerSettings.Region = ipj_region.E_IPJ_REGION_BRAZIL_902_907_AND_915_928_MHZ;

                // Enable rssi report
                readerSettings.ReportSettings.IncludeRssi = true;

                // Enable unique manufacturer identification report
                readerSettings.ReportSettings.IncludeTid = false;

                // Configure tag population
                readerSettings.TagPopulationEstimate = 16;

                // Configure read mode
                readerSettings.SearchMode = SearchMode.SingleTarget;

                // Configure session mode
                readerSettings.Session = 1;

                // Configure Power
                readerSettings.TxPower = 10;

                // Apply settings
                ReaderHelper.Instance.ApplyReaderSettings(readerSettings);

                // Start inventory
                ReaderHelper.Instance.Start();

                int counter = 0;
                while (counter < 10)
                {
                    Thread.Sleep(100);
                    counter++;
                }

                // Stop inventory
                ReaderHelper.Instance.Stop();

                // Disconnect
                ReaderHelper.Instance.Disconnect();

                Console.WriteLine("Press any key to continue...");
                Console.ReadLine();
            }
            catch (Exception ex)
            {
                Console.WriteLine("Unexpected error: " + ex.Message);

                Console.WriteLine("Press any key to continue...");
                Console.ReadLine();
            }
        }

        // The tag read handler
        private static void OnTagReported(Tag tagReported)
        {
            if (tagReported.IsRssiInDbmPresent && tagReported.IsTidPresent)
                Console.WriteLine("EPC: " + tagReported.Epc + ", TID: " + tagReported.Tid + ", RSSI: " + tagReported.RssiInDbm);
            else if (tagReported.IsRssiInDbmPresent)
                Console.WriteLine("EPC: " + tagReported.Epc + ", RSSI: " + tagReported.RssiInDbm);
            else if (tagReported.IsTidPresent)
                Console.WriteLine("EPC: " + tagReported.Epc + ", TID: " + tagReported.Tid);
            else
                Console.WriteLine("EPC: " + tagReported.Epc);
        }
    }
}