﻿// Copyright (c) 2020, Identix identix@identix.com.br
// 
// Permission to use, copy, modify, and/or distribute this software for any purpose with or without fee is hereby granted, provided that the above copyright notice and this permission notice appear in all copies.
// 
// THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

using System;
using System.Threading;
using IRI.Win32.CSharp.IRIWrapper;

namespace Identix.SerialSDK.Examples.WriteAccessPassword
{
    /// <summary>
    ///  IRI Wrapper example on how to write the access password on reserved bank
    /// </summary>
    class Program
    {
        private static string targetEpc = "000000000000000000000000";
        private static string currentAccessPassword = "00000000";
        private static string newAccessPassword = "11111111";

        static void Main(string[] args)
        {
            try
            {
                Console.Write("Inform the COM port number: ");
                string comPort = Console.ReadLine();
                Console.WriteLine("COM{0}", comPort);

                // Register the callbacks
                ReaderHelper.Instance.TagOpCompleted += OnTagOpCompleted;

                // Connect to COM port, make sure to have installed compatible driver                
                ReaderHelper.Instance.Connect("COM" + comPort.Trim());

                // As a good practice we will reset the reader to clean up old configurations
                ReaderHelper.Instance.SoftReset();

                ipj_error result = ReaderHelper.Instance.ChangeAccessPassword(targetEpc, newAccessPassword, currentAccessPassword);
                Thread.Sleep(300);

                Console.WriteLine("Result:" + result);

                // Disconnect
                ReaderHelper.Instance.Disconnect();

                Console.WriteLine("Press any key to continue...");
                Console.ReadLine();
            }
            catch (Exception ex)
            {
                Console.WriteLine("Unexpected error: " + ex.Message);

                Console.WriteLine("Press any key to continue...");
                Console.ReadLine();
            }
        }

        // The tag operation handler
        private static void OnTagOpCompleted(TagOpResult tagOpResult)
        {
            Console.WriteLine("Op ID: " + tagOpResult.TagOpId + ", result: " + tagOpResult.Result);
        }
    }
}